/** @module @codefresh-io/cf-variable-resolver */
/**
 * Variable resolver options
 * @typedef {Object} Options
 * @property {number | undefined} singleResolutionTimeout - sets the timeout for single variable resolution
 * @property {number | undefined} completeResolutionFlowTimeout - sets the timeout for the entire resolution
 * @property {Logger | undefined} log - sets the timeout for the entire resolution
 * @property {function(string, Object, Logger): Promise<*>} getContext - a function used by the variable resolver to retrieve contexts
 * @property {function(Resolution, Logger): Promise<void> | undefined} addNewMask - a function used by the variable resolver to add a new mask
 */
/**
 * Builds a new variable resolver
 * @param {Object.<string, Resolver>} resolvers resolvers
 * @param {Options} options options
 * @returns {VariableResolver} variableResolver
 */
export function build(resolvers: {
    [x: string]: any;
}, options: Options): any;
/**
 * Variable resolver options
 */
export type Options = {
    /**
     * - sets the timeout for single variable resolution
     */
    singleResolutionTimeout: number | undefined;
    /**
     * - sets the timeout for the entire resolution
     */
    completeResolutionFlowTimeout: number | undefined;
    /**
     * - sets the timeout for the entire resolution
     */
    log: any | undefined;
    /**
     * - a function used by the variable resolver to retrieve contexts
     */
    getContext: (arg0: string, arg1: any, arg2: any) => Promise<any>;
    /**
     * - a function used by the variable resolver to add a new mask
     */
    addNewMask: (arg0: any, arg1: any) => Promise<void> | undefined;
};
/**
 * resolveKey options
 */
export type ResolveKeyOptions = {
    /**
     * - resolvers
     */
    resolvers: {
        [x: string]: any;
    };
    /**
     * - key
     */
    key: string;
    /**
     * - index
     */
    index: number;
    /**
     * - timeout for single variable resolution
     */
    timeout: number | null;
    /**
     * - logger
     */
    log: any;
    /**
     * - a function used by the variable resolver to retrieve contexts
     */
    getContext: (arg0: string, arg1: any, arg2: any) => Promise<any>;
    /**
     * - a function used by the variable resolver to add a new mask
     */
    addNewMask: (arg0: any, arg1: any) => Promise<void> | undefined;
};
declare const Promise: any;
export {};
